#
# spec file for package dos2unix
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dos2unix
Version:        7.5.1
Release:        1.1
Summary:        Text converters to and from DOS/MAC to UNIX
License:        BSD-2-Clause
Group:          Productivity/Text/Convertors
URL:            https://waterlan.home.xs4all.nl/dos2unix.html
Source0:        https://waterlan.home.xs4all.nl/dos2unix/dos2unix-%{version}.tar.gz
Source1:        https://waterlan.home.xs4all.nl/dos2unix/dos2unix-%{version}.tar.gz.asc
# http://keys.gnupg.net/pks/lookup?op=get&search=0x38C1F572B12725BE
Source2:        %{name}.keyring
Provides:       unix2dos = %{version}
Obsoletes:      unix2dos < %{version}

%description
Dos2unix is used to convert plain text from DOS (CR/LF) format. Mac2unix
converts plain text from MAC (CR) format to UNIX format (LF).

Unix2dos converts plain text files from UNIX
format to DOS format and unix2dos converts from UNIX to MAC format.

%prep
%setup -q
find . -type f -exec chmod -x '{}' +

%build
export RPM_OPT_FLAGS
%make_build CC="gcc" HTMLEXT="html"

%install
%make_install docdir=%{_defaultdocdir}/%{name} HTMLEXT="html"
%find_lang dos2unix --all-name --with-man
rm %{buildroot}%{_defaultdocdir}/%{name}/COPYING.txt

%files -f dos2unix.lang
%license COPYING.txt
%doc %{_defaultdocdir}/%{name}
%{_bindir}/{%{name},mac2unix,unix2dos,unix2mac}
%{_mandir}/man1/{%{name},mac2unix,unix2dos,unix2mac}.1%{?ext_man}
%dir %{_mandir}/??

%changelog
* Wed Aug 30 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 7.5.1:
  * Fix problem of converting a symbolic link target that is on
    another file system
  * Updated Chinese and Serbian translations
* Thu May 18 2023 Andreas Stieger <Andreas.Stieger@gmx.de>
- update to 7.5.0:
  * New option -e, --add-eol to add a line break to the last line
    if the isn't one
  * New option -O, --to-stdout to write to standard output
* Sun Feb 12 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 7.4.4:
  * translation updates
* Mon Jun  6 2022 Илья Индиго <ilya@ilya.cf>
- Added directory with localized man pages.
* Sun Jun  5 2022 Erwin Waterlander <waterlan@xs4all.nl>
- update to 7.4.3:
  * translation update
* Thu Feb 11 2021 Antoine Belvire <antoine.belvire@opensuse.org>
- Remove localized man directories from file list: Already provided
  by filesystem.
* Thu Oct 15 2020 Andreas Stieger <andreas.stieger@gmx.de>
- update to 7.4.2:
  * translation update
- add upstream signing key and verify source signature
* Wed Sep 25 2019 Andreas Stieger <andreas.stieger@gmx.de>
- update to 7.4.1:
  * translation updates
  * code cleanup
* Wed Oct 11 2017 waterlan@xs4all.nl
- Update to 7.3.5
  * New option --allow-chown to allow file ownership change
    in old file mode.
* Mon Jul 10 2017 jengelh@inai.de
- Replace suboptimal find \;
* Thu Jul  6 2017 dimstar@opensuse.org
- Use find -exec instead of find | xargs: helps handle cases for
  files with spaces and quotes in their filenames.
* Wed Jul  5 2017 waterlan@xs4all.nl
- Update to 7.3.5
* Wed May 25 2016 waterlan@xs4all.nl
- Update to 7.3.4
* Sun Feb 14 2016 waterlan@xs4all.nl
- Update to 7.3.3
* Fri Nov 20 2015 waterlan@xs4all.nl
- Update to 7.3.2
  * New: Swedish translation of messages and manual.
  * Updated: Danish and Brazilian Portuguese translations.
  * Fix: The -iso option was misinterpreted as a corrupted -i option.
  * Fix: Compilation for MSYS 1.
* Thu Oct  1 2015 waterlan@xs4all.nl
- Update to 7.3.1
  * New: Simplified Chinese translation of messages and manual.
  * Fix: Compilation error "'wchar_t' undeclared" when Unicode support is disabled.
  * Fix: Compilation errors when MinGW compiler was used (MinGW-w64 was OK).
* Tue Aug 25 2015 waterlan@xs4all.nl
- Update to 7.3
  * New: Unicode file name support on Windows.
  * Fix: Options -ul and -ub caused option -i to report wrong BOM for no_bom.
* Fri Jul  3 2015 waterlan@xs4all.nl
- Update to 7.2.3
  * Fix: Check for file I/O errors while reading input files, and added
    a few missing checks while writing output files.
  * Fix: Compilation for msys.
* Sat May 23 2015 waterlan@xs4all.nl
- Update to 7.2.2
  * Fix: Fixed symlink support on FreeBSD.
  * Fix: Skip GB18030 test on FreeBSD.
  * Fix: When conversion of an UTF-16 file with binary symbols was forced,
    null characters were not written in the output.
  * Fix: Check UTF-16 input for invalid surrogate pairs.
* Thu Apr  2 2015 waterlan@xs4all.nl
- Update to 7.2.1
  * Fix: Skip the GB18030 tests when the system does not support the
    Chinese locale with GB18030 character encoding.
  * Fix: Small corrections in the manual in section GB18030 and OPTIONS -m.
* Sun Feb 15 2015 waterlan@xs4all.nl
- Update to 7.2
  * New: Japanese translation of the UI messages.
  * New: Support Chinese GB18030 locale.
  * Change: On Unix/Linux convert UTF-16 to the locale encoding. It is
    no longer required that the locale encoding is UTF-8.
* Sun Oct 26 2014 waterlan@xs4all.nl
- Fixed license type: BSD-2-Clause
- Added missing manual translations: da, fr, pt_BR.
- Update to 7.1:
  * New: Option -i, --info to print file information.
    This new option prints number of DOS, Unix, and Mac line breaks, the byte
    order mark, and if the file is text or binary. And it can print the names
    of files that would be converted.
  Version 7.0
  * New: automated self-tests.
  * New: option -u to keep UTF-16 encoding.
  * New: option -v to print information about BOMs and converted line breaks.
  * Change: stdio mode does not automatically set quiet mode.
  * Change: stdio mode does not automatically force conversion of binaries.
    An error is returned when the stdin stream contains a binary symbol.
  * Bugfix: dos2unix -l created DOS line breaks from Mac line breaks.
  * Bugfix: system error number was not always returned.
  * Bugfix: an Unicode input file disabled 7bit and iso mode for next input files.
  * Bugfix: mac2unix help text, options -b and -r.
  * The code has been cleaned up.
* Mon Aug  4 2014 pth@suse.de
- Update to 6.0.6:
  * Bugfix: mac2unix conversion produced corrupted output from
    UTF-16 input file.
  * New options -b (keep BOM) and -r (remove BOM).
  * New translation of the UI messages: Norwegian Bokmaal.
* Tue Apr 22 2014 tabraham@suse.com
- Update to 6.0.5
  * Dos2unix is part of the Translation Project (TP).
    All translations go via the Translation Project.
    See http://translationproject.org/
  * New translations of UI messages: Brazilian Portuguese, Chinese (traditional),
    Danish, French, Hungarian, Polish, Serbian, Ukrainian, Vietnamese.
  * New translations of the manual: Brazilian Portuguese, French, German,
    Polish, Ukrainian.
  * Generated man pages are included in the source package to prevent
    compilation problems with very old or very new perl/pod2man versions.
  * Manuals are now generated from gettext PO files with po4a for easier
    translation.
  * All manuals are now in UTF-8 encoding.
  * Skip symbolic links on Windows by default (same as on Unix).
* Sun Jan  5 2014 tabraham@suse.com
- Update to 6.0.4.
  * New options -ul and -ub to conver UTF-16 files without BOM
  * New Russian translation of the messages
  * Build 32 bit Windows binaries with Large File Support (LFS) by
    using mingw-w64 for 32 bit Windows
  * When a binary symbol is encountered the value is printed
* Tue Apr 16 2013 pth@suse.de
- Update to 6.0.3. Changes since 6.0:
  - Version 6.0.3
  * Source code compiles with Microsoft Visual C.
  * Print system error when writing output fails.
  - Version 6.0.2
  * The locale encoding detection when NLS was disabled has been fixed.
  * Print line number when a binary symbol is found.
  * Updated makefiles for Watcom C, and added a new one for OS/2.
  - Version 6.0.1
  * Update Spanish translations.
  * Update manual.
* Mon Jul 16 2012 andreas.stieger@gmx.de
- fix build against openSUSE:Factory / standard: man page paths
* Sun May  6 2012 pascal.bleser@opensuse.org
- update to 6.0:
  * Conversion of Windows UTF-16 files to Unix UTF-8 files
  * Conversion of Unix UTF-8 files to Windows UTF-8 files with byte
    order mark
* Mon Mar 12 2012 tabraham@novell.com
- Update to 5.3.3:
  - enabled wildcard expansion
  - small update in RETURN VALUE section of man page
- removed dos2unix-correct_ending.patch (instead pass HTMLEXT="html"
  to make)
* Mon Jan 30 2012 pth@suse.de
- Update to 5.3.2:
  - Change of hmoepage URL.
  - All other changes are for non Unix platforms.
  - Don't recompress the package anymore.
* Fri Sep 30 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
* Wed Aug 10 2011 pth@suse.de
- Update to 5.3.1:
  * Spanish tranlation of messages and manual.
  * File ownership is maintained in old file mode (Unix only).
  * Dos2unix and Unix2dos share the same language files.
  * Code cleanup.
* Wed May 25 2011 aj@suse.de
- Add buildrequire on xz.
* Mon May 23 2011 pth@suse.de
- Repackage with xz.
* Sat May 21 2011 crrodriguez@opensuse.org
- Open all fds with O_CLOEXEC.
* Sat May 21 2011 vlado.paskov@gmail.com
- Version update to 5.3
  - removed patch dos2unix-no_pdf.patch, this version doesn't
    generate pdf/ps documents.
  - updated dos2unix-correct_ending.patch
  - fixed Url: in the spec file
* Tue Feb 15 2011 pth@suse.de
- Don't generate ps/pdf documents, thus no need for ghostscript.
* Thu Feb  3 2011 pth@suse.de
- Update to 5.2:
    ISO conversion mode supports same DOS code pages as SunOS dos2unix does:
    CP437 (US), CP850 (Western European), CP860 (Portuguese),
    CP863 (French Canadian), and CP865 (Nordic).
    ISO conversion mode supports Windows code page CP1252 (Western).
    SunOS compatible options -ascii, -iso, -7, -437, -850, -860, -863, and -865.
    Active code page detection for ISO mode.
    Fixed ISO conversion of non-breaking space (NBSP).
    Treat ASCII Form Feed control characters as valid text.
    Update manual pages.
    Don't include generated documentation files in Unix source package.
- Suffix for HTML pages is .html not .htm
* Fri Jan 14 2011 coolo@novell.com
- remove unsupported locales
* Wed Nov 10 2010 coolo@novell.com
- fix file list
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Tue Aug 24 2010 pth@suse.de
- Update 5.1.1:
  * Added Dutch translation of the manual
  * Updated German translation
* Sat Apr 10 2010 aj@suse.de
- Add eo-x directories to fix build.
* Tue Apr  6 2010 pth@novell.com
- Update to 5.1:
  * Esperanto translations have been added.
  * Command-line options can be set in stdio mode.
  * Localization information has been added to the manual.
  * Man pages have been merged.
  * Man page generation from Perl POD file.
* Wed Feb 17 2010 pth@suse.de
- Update to 5.0:
  * Dos2unix and Unix2dos have been bundled in a single package.
  * German translations have been added.
  * Dos2unix -l --newline also works in MAC mode.
  * Unix2dos also got option -l, --newline.
  * Added MAC mode to Unix2dos: Convert Unix line endings to Mac line endings.
  * Cleanup of messages and manual.
* Wed Feb  3 2010 pth@suse.de
- Update to 4.1.2:
  * dos2unix.c: Preserve file mode in 'new file mode'.
  * Makefile: Allow CFLAGS to be set externally.
- Adapt Makefile patch and German message catalog.
* Tue Dec 22 2009 coolo@novell.com
- fix translation
* Wed Dec 16 2009 pth@suse.de
- Update to 4.0:
  * version 4.0
  * Added internationalisation using gettext.
  * Added Dutch translation.
  * New option -L/--license that prints software license.
  * Code cleanup
  * Update manual
  * version 3.2
  * version.mk: New file.
  * README: New file.
  * INSTALL: Updated.
  * Makefile: Makefile according GNU standards.
  * ChangeLog : New file.
  * Applied all patches from RedHat:
- Use DESTDIR only in install makefile targets.
- Add a German translation.
* Tue Dec 15 2009 jengelh@medozas.de
- enable parallel building
* Mon Apr 20 2009 pth@suse.de
- Don't destroy original file if the output is on a different file
  system (bnc#488261).
* Tue Dec  9 2008 schwab@suse.de
- Fix last change.
* Mon Sep 15 2008 ro@suse.de
- let mac2unix be a hardlink (instead of duplicate binary)
* Tue Apr 11 2006 pth@suse.de
- Make dos2unix preserve file modes (bugzilla #119350).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct  5 2005 dmueller@suse.de
- add norootforbuild
* Mon Aug 12 2002 bk@suse.de
- update to dos2unix-3.1(no longer uses hd2u, but real dos2unix)
* Wed Jun 19 2002 postadal@suse.cz
- new package dos2unix verison 0.8.0
